@@ -205,7 +205,8 @@ def display3(videodev, save = False,
 # ================================================================================================
 
 def display2(videodev, save = False,
-         passfile="~/.pycamfw_userpass"):
+             passfile="~/.pycamfw_userpass",
+             rotate = 0):
     """
     """
     #sname,sfilenamea,sme,sfilenamea,sfilenamea,sfourcc,saviout
@@ -493,7 +494,13 @@ def display2(videodev, save = False,
                         senh.setbox(f"JPG",  senh.jpg)
                         frame = senh.get_frame(  )
 
-                cv2.imshow(rpi_name, frame) # 1 window for each RPi
+                if rotate == 180:
+                    frame = cv2.rotate(frame, cv2.ROTATE_180)
+                    #frame = cv2.rotate(frame, cv2.ROTATE_90_CLOCKWISE)
+
+                cv2.imshow(rpi_name, frame, ) # 1 window for each RPi
+                #cv2.setWindowProperty(rpi_name, cv2.WND_PROP_TOPMOST, 1)
+                # cv2.namedWindow(rpi_name, cv2.WINDOW_GUI_EXPANDED)
                 # time.sleep(0.2)
                 key = cv2.waitKey(1)
 
