@@ -65,6 +65,10 @@ class V4L2_Control:
         return self.default
 
     def change_value(self, value):
+        if value> self.max:
+            value = self.max
+        if value< self.min:
+            value = self.min
         try:
             value = int(value)
         except Exception as e:
@@ -72,11 +76,11 @@ class V4L2_Control:
             return -1
 
         if self.step != -99 and value < self.min:
-            print("change_value: Value too little")
+            print("change_value: Value too little", value," x ",self.min)
             return -1
 
         if self.step != -99 and value > self.max:
-            print("change_value: Value too big")
+            print("change_value: Value too big", value," x ",self.max)
             return -1
 
         if self.step != -99 and value % self.step != 0:
