@@ -186,6 +186,11 @@ setInterval(doDate, 200);
  <td>
     <button style="width:100%" name="subbg" value="SUBBG">subBG</button>
  </td>
+ <td> </td>
+ <td>
+   <button style="width:100%" name="rot0" value="ROT0">rot0</button>
+   <button style="width:100%" name="rot180" value="ROT180">rot180</button>
+ </td>
 </tr>
 </table>
 
@@ -333,8 +338,10 @@ def cross():
             except:
                 print("D... unknown value timelaps")
 
-
-
+        if request.form.get('rot0') == 'ROT0':
+            mmwrite(f"rotate180 False" )
+        if request.form.get('rot180') == 'ROT180':
+            mmwrite(f"rotate180 True" )
 
 
         # ---------------------------------------------- Cross controls
